package com.ruoyi.tcZz.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.tcZz.domain.TcYtlc;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.tcZz.mapper.TcZbxqMapper;
import com.ruoyi.tcZz.domain.TcZbxq;
import com.ruoyi.tcZz.service.ITcZbxqService;

/**
 *  转办量、转办详情Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@Service
public class TcZbxqServiceImpl implements ITcZbxqService 
{
    @Autowired
    private TcZbxqMapper tcZbxqMapper;

    /**
     * 查询 转办量、转办详情
     * 
     * @param id  转办量、转办详情主键
     * @return  转办量、转办详情
     */
    @Override
    public TcZbxq selectTcZbxqById(Long id)
    {
        return tcZbxqMapper.selectTcZbxqById(id);
    }

    /**
     * 查询 转办量、转办详情列表
     * 
     * @param tcZbxq  转办量、转办详情
     * @return  转办量、转办详情
     */
    @Override
    public List<TcZbxq> selectTcZbxqList(TcZbxq tcZbxq)
    {
        return tcZbxqMapper.selectTcZbxqList(tcZbxq);
    }

    /**
     * 新增 转办量、转办详情
     * 
     * @param tcZbxq  转办量、转办详情
     * @return 结果
     */
    @Override
    public int insertTcZbxq(TcZbxq tcZbxq)
    {
        tcZbxq.setCreateTime(DateUtils.getNowDate());
        return tcZbxqMapper.insertTcZbxq(tcZbxq);
    }

    /**
     * 修改 转办量、转办详情
     * 
     * @param tcZbxq  转办量、转办详情
     * @return 结果
     */
    @Override
    public int updateTcZbxq(TcZbxq tcZbxq)
    {
        tcZbxq.setUpdateTime(DateUtils.getNowDate());
        return tcZbxqMapper.updateTcZbxq(tcZbxq);
    }

    /**
     * 批量删除 转办量、转办详情
     * 
     * @param ids 需要删除的 转办量、转办详情主键
     * @return 结果
     */
    @Override
    public int deleteTcZbxqByIds(Long[] ids)
    {
        return tcZbxqMapper.deleteTcZbxqByIds(ids);
    }

    /**
     * 删除 转办量、转办详情信息
     * 
     * @param id  转办量、转办详情主键
     * @return 结果
     */
    @Override
    public int deleteTcZbxqById(Long id)
    {
        return tcZbxqMapper.deleteTcZbxqById(id);
    }

    @Override
    public String importUser(List<TcZbxq> tcZbxqList) {
        StringBuilder successMsg = new StringBuilder();
        if (!tcZbxqList.isEmpty()) {
            for (TcZbxq tcZbxq : tcZbxqList) {
                tcZbxqMapper.insertTcZbxq(tcZbxq);
            }
            successMsg.append("导入成功");
        }
        return successMsg.toString();
    }


    @Override
    public void updateByisStatus(Integer isStatus,List<String> ids) {
        tcZbxqMapper.updateByisStatus(isStatus,ids);
    }
}
