package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcYtlc;
import com.ruoyi.tcZz.domain.TcZbxq;
import com.ruoyi.tcZz.service.ITcZbxqService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 转办量、转办详情Controller
 *
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "转办量、转办详情")
@RequestMapping("/tcZz/netWorkYq/zbxq")
public class TcZbxqController extends BaseController {
    @Autowired
    private ITcZbxqService tcZbxqService;

    /**
     * 查询 转办量、转办详情列表
     */
    @ApiOperation(value = "查询 转办量、转办详情列表", response = TcZbxq.class)
    @GetMapping("/list")
    public TableDataInfo list(TcZbxq tcZbxq) {
        startPage();
        List<TcZbxq> list = tcZbxqService.selectTcZbxqList(tcZbxq);
        return getDataTable(list);
    }

    /**
     * 导出 转办量、转办详情列表
     */
    @ApiOperation(value = " 导出 转办量、转办详情列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZbxq tcZbxq) {
        List<TcZbxq> list = tcZbxqService.selectTcZbxqList(tcZbxq);
        ExcelUtil<TcZbxq> util = new ExcelUtil<TcZbxq>(TcZbxq.class);
        util.exportExcel(response, list, " 转办量、转办详情数据");
    }

    /**
     * 获取 转办量、转办详情详细信息
     */
    @ApiOperation(value = " 获取 转办量、转办详情详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcZbxqService.selectTcZbxqById(id));
    }

    /**
     * 新增 转办量、转办详情
     */
    @ApiOperation(value = "新增 转办量、转办详情")
    @PostMapping
    public AjaxResult add(@RequestBody TcZbxq tcZbxq) {
        return toAjax(tcZbxqService.insertTcZbxq(tcZbxq));
    }

    /**
     * 修改 转办量、转办详情
     */
    @ApiOperation(value = "修改 转办量、转办详情")
    @PutMapping
    public AjaxResult edit(@RequestBody TcZbxq tcZbxq) {
        return toAjax(tcZbxqService.updateTcZbxq(tcZbxq));
    }

    /**
     * 删除 转办量、转办详情
     */
    @ApiOperation(value = " 删除 转办量、转办详情")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcZbxqService.deleteTcZbxqByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcZbxq> util = new ExcelUtil<TcZbxq>(TcZbxq.class);
        List<TcZbxq> tcZbxqList = util.importExcel(file.getInputStream());
        tcZbxqService.importUser(tcZbxqList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus,@RequestParam("ids") List<String> ids) {
        tcZbxqService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcZbxq> util = new ExcelUtil<TcZbxq>(TcZbxq.class);
        util.importTemplateExcel(response, " 转办量、转办详情");
    }
}
